==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault.md <==
# AmazonSimpleStorageServiceGlacierVault


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')
```



| Illustration | AmazonSimpleStorageServiceGlacierVault | AmazonSimpleStorageServiceGlacierVaultCard | AmazonSimpleStorageServiceGlacierVaultGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault.png) | ![illustration for AmazonSimpleStorageServiceGlacierVault](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierVaultCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVaultCard.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierVaultGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVaultGroup.Local.png) |




## AmazonSimpleStorageServiceGlacierVault

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVault
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVault('AmazonSimpleStorageServiceGlacierVault', 'Amazon Simple Storage Service Glacier Vault', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVault
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVault('AmazonSimpleStorageServiceGlacierVault', 'Amazon Simple Storage Service Glacier Vault', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceGlacierVaultCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultCard('AmazonSimpleStorageServiceGlacierVaultCard', 'Amazon Simple Storage Service Glacier Vault Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultCard('AmazonSimpleStorageServiceGlacierVaultCard', 'Amazon Simple Storage Service Glacier Vault Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceGlacierVaultGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultGroup('AmazonSimpleStorageServiceGlacierVaultGroup', 'Amazon Simple Storage Service Glacier Vault Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultGroup('AmazonSimpleStorageServiceGlacierVaultGroup', 'Amazon Simple Storage Service Glacier Vault Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault.md <==
# AmazonSimpleStorageServiceGlacierVault


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')
```



| Illustration | AmazonSimpleStorageServiceGlacierVault | AmazonSimpleStorageServiceGlacierVaultCard | AmazonSimpleStorageServiceGlacierVaultGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault.png) | ![illustration for AmazonSimpleStorageServiceGlacierVault](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierVaultCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVaultCard.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierVaultGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVaultGroup.Local.png) |




## AmazonSimpleStorageServiceGlacierVault

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVault
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVault('AmazonSimpleStorageServiceGlacierVault', 'Amazon Simple Storage Service Glacier Vault', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVault
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVault('AmazonSimpleStorageServiceGlacierVault', 'Amazon Simple Storage Service Glacier Vault', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceGlacierVaultCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultCard('AmazonSimpleStorageServiceGlacierVaultCard', 'Amazon Simple Storage Service Glacier Vault Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultCard('AmazonSimpleStorageServiceGlacierVaultCard', 'Amazon Simple Storage Service Glacier Vault Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceGlacierVaultGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultGroup('AmazonSimpleStorageServiceGlacierVaultGroup', 'Amazon Simple Storage Service Glacier Vault Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierVaultGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierVault')

' renders the element
AmazonSimpleStorageServiceGlacierVaultGroup('AmazonSimpleStorageServiceGlacierVaultGroup', 'Amazon Simple Storage Service Glacier Vault Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
